@@ -10,7 +10,7 @@ package Math::String::Charset::Grouped;
 use base Math::String::Charset;
 
 use vars qw($VERSION);
-$VERSION = 0.02;	# Current version of this package
+$VERSION = 0.03;	# Current version of this package
 require  5.005;		# requires this Perl version or later
 
 use strict;
@@ -34,6 +34,7 @@ $die_on_error = 1;              # set to 0 to not die
 # _cnum  : number of characters in _ones as BigInt (for speed)
 # _minlen: minimum string length (anything shorter is invalid), default -inf
 # _maxlen: maximum string length (anything longer is invalid), default +inf
+# _scale : optional input/output scale
 
 # simple ones:
 # _sep  : separator string (undef for none)
@@ -65,7 +66,7 @@ sub _strict_check
   foreach my $key (keys %$value)
     {
     return $self->{_error} = "Illegal parameter '$key' for $class"
-      if $key !~ /^(start|minlen|maxlen|sep|sets|end|charlen)$/;
+      if $key !~ /^(start|minlen|maxlen|sep|sets|end|charlen|scale)$/;
     }
   }
 
